#line 2 "gtkdialog_lexer.c"

#line 4 "gtkdialog_lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer gtkdialog__create_buffer
#define yy_delete_buffer gtkdialog__delete_buffer
#define yy_flex_debug gtkdialog__flex_debug
#define yy_init_buffer gtkdialog__init_buffer
#define yy_flush_buffer gtkdialog__flush_buffer
#define yy_load_buffer_state gtkdialog__load_buffer_state
#define yy_switch_to_buffer gtkdialog__switch_to_buffer
#define yyin gtkdialog_in
#define yyleng gtkdialog_leng
#define yylex gtkdialog_lex
#define yylineno gtkdialog_lineno
#define yyout gtkdialog_out
#define yyrestart gtkdialog_restart
#define yytext gtkdialog_text
#define yywrap gtkdialog_wrap
#define yyalloc gtkdialog_alloc
#define yyrealloc gtkdialog_realloc
#define yyfree gtkdialog_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE gtkdialog_restart(gtkdialog_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int gtkdialog_leng;

extern FILE *gtkdialog_in, *gtkdialog_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gtkdialog_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up gtkdialog_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via gtkdialog_restart()), so that the user can continue scanning by
	 * just pointing gtkdialog_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when gtkdialog_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int gtkdialog_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow gtkdialog_wrap()'s to do buffer switches
 * instead of setting up a fresh gtkdialog_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void gtkdialog_restart (FILE *input_file  );
void gtkdialog__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE gtkdialog__create_buffer (FILE *file,int size  );
void gtkdialog__delete_buffer (YY_BUFFER_STATE b  );
void gtkdialog__flush_buffer (YY_BUFFER_STATE b  );
void gtkdialog_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void gtkdialog_pop_buffer_state (void );

static void gtkdialog_ensure_buffer_stack (void );
static void gtkdialog__load_buffer_state (void );
static void gtkdialog__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER gtkdialog__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE gtkdialog__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE gtkdialog__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE gtkdialog__scan_bytes (yyconst char *bytes,int len  );

void *gtkdialog_alloc (yy_size_t  );
void *gtkdialog_realloc (void *,yy_size_t  );
void gtkdialog_free (void *  );

#define yy_new_buffer gtkdialog__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        gtkdialog_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gtkdialog__create_buffer(gtkdialog_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        gtkdialog_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gtkdialog__create_buffer(gtkdialog_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *gtkdialog_in = (FILE *) 0, *gtkdialog_out = (FILE *) 0;

typedef int yy_state_type;

extern int gtkdialog_lineno;

int gtkdialog_lineno = 1;

extern char *gtkdialog_text;
#define yytext_ptr gtkdialog_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up gtkdialog_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	(yytext_ptr) -= (yy_more_len); \
	gtkdialog_leng = (size_t) (yy_cp - (yytext_ptr)); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 185
#define YY_END_OF_BUFFER 186
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[453] =
    {   0,
      186,  177,  184,  185,  183,  184,  185,  182,  185,  173,
      184,  185,    2,  177,  184,  185,  184,  185,    1,  184,
      185,  184,  185,   17,  184,  185,    2,  184,  185,   14,
      184,  185,   16,  184,  185,   14,   15,  184,  185,   15,
      184,  185,    6,  184,  185,    3,  184,  185,    4,  184,
      185,    5,  184,  185,    7,  184,  185,    7,  183,  184,
      185,    7,  182,  185,    9,  184,  185,    2,    7,  184,
      185,  184,  185,  178,  184,  185,  178,  183,  184,  185,
        2,  178,  184,  185,  181,  184,  185,  184,  185,  174,
      184,  185,  174,  183,  184,  185,  174,  182,  185,  176,

      184,  185,    2,  174,  184,  185,  184,  185,  177,    2,
      177,    2,  172,   16,   15,    3,    7,    2,    7,    8,
      178,    2,  178,  180,  179,  180,  174,    2,  174,  175,
      171,  172,   19,  171,  172,   46,   45,  172,   73,  172,
       31,   30,  172,  146,  144,  172,   79,   78,  172,   88,
       87,  172,   37,   36,  172,   49,   48,  172,   28,   27,
      172,   47,  171,  172,   74,  171,  172,   32,  171,  172,
      145,  171,  172,   80,  171,  172,   89,  171,  172,   38,
      171,  172,   50,  171,  172,   29,  171,  172,   44,   42,
      172,   33,  172,  161,  157,  172,  142,  172,   71,  172,

       10,  172,   82,   81,  172,  119,  118,  172,  155,  172,
       43,  171,  172,   35,  171,  172,  158,  171,  172,  143,
      171,  172,   72,  171,  172,   83,  171,  172,  120,  171,
      172,   20,  171,  172,  156,  171,  172,  169,  168,  172,
    16440,   54,  172,  153,  172,  110,  109,  172,  161,  162,
      172,   41,   39,  172,  113,  112,  172,   22,   21,  172,
      170,  171,  172,   55,  171,  172,  154,  171,  172,  111,
      171,  172,  163,  171,  172,   40,  171,  172,  114,  171,
      172,   23,  171,  172,16440, 8248,   53,   51,  172,  147,
      172,   34,   85,   84,  172,  149,  172,   52,  171,  172,

       18,  171,  172,  148,  171,  172,   86,  171,  172,  150,
      171,  172,   64,   62,  172,   76,   75,  172,  137,  136,
      172,  140,  139,  172,   91,   90,  172,   25,   24,  172,
      134,  133,  172,  166,  165,  172,   63,  171,  172,   77,
      171,  172,  138,  171,  172,  141,  171,  172,   92,  171,
      172,   26,  171,  172,  135,  171,  172,  167,  171,  172,
       61,   57,  151,  172,   95,  172,  125,  124,  172,  152,
      171,  172,   96,  171,  172,  126,  171,  172,   60,  131,
      130,  172,   98,   97,  172,  160,  159,  116,  115,  172,
      101,  100,  172,  132,  171,  172,   99,  171,  172,  117,

      171,  172,  102,  171,  172,   59,  128,  127,  172,  164,
       70,   68,  172,   67,   65,  172,  129,  171,  172,   69,
      171,  172,   66,  171,  172,  104,  103,  172,  122,  121,
      172,  105,  171,  172,  123,  171,  172,   58,  107,  106,
      172,   12,  108,  171,  172,   13,   93,  172,   94,  171,
      172,   11
    } ;

static yyconst flex_int16_t yy_accept[923] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    2,    5,    8,   10,   13,   17,   19,
       22,   24,   27,   30,   33,   36,   40,   43,   46,   49,
       52,   55,   58,   62,   65,   68,   72,   74,   77,   81,
       85,   88,   90,   93,   97,  100,  103,  107,  109,  110,
      112,  113,  113,  113,  114,  114,  114,  114,  114,  114,
      114,  114,  114,  114,  114,  114,  114,  114,  114,  114,
      114,  114,  114,  114,  115,  116,  117,  118,  120,  121,
      122,  124,  125,  127,  128,  130,  131,  131,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,

      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,

      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,

      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  137,  139,
      139,  139,  139,  139,  139,  141,  142,  144,  144,  144,

      144,  144,  144,  145,  147,  147,  148,  150,  151,  153,
      153,  153,  153,  153,  153,  153,  153,  153,  153,  153,
      153,  153,  153,  153,  154,  156,  156,  156,  157,  159,
      159,  160,  162,  162,  162,  162,  162,  162,  162,  162,
      162,  162,  162,  162,  162,  162,  162,  165,  165,  165,
      165,  165,  165,  168,  171,  171,  171,  171,  171,  174,
      174,  177,  180,  180,  180,  180,  180,  180,  180,  180,
      180,  180,  180,  180,  180,  180,  183,  183,  183,  186,
      186,  189,  189,  189,  189,  189,  189,  189,  189,  189,
      189,  189,  189,  189,  189,  189,  190,  192,  192,  192,

      192,  192,  194,  194,  194,  194,  194,  195,  197,  199,
      199,  199,  199,  199,  199,  199,  201,  201,  201,  201,
      203,  203,  203,  204,  206,  206,  207,  209,  209,  209,
      209,  209,  209,  209,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  214,  214,  214,  214,  217,  217,
      217,  217,  220,  223,  223,  223,  223,  223,  223,  223,
      226,  226,  226,  226,  226,  226,  229,  229,  232,  232,
      232,  232,  232,  232,  235,  238,  238,  239,  241,  242,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  246,  247,  249,  249,  249,  250,  250,  250,  250,

      250,  250,  252,  253,  255,  255,  255,  255,  255,  255,
      255,  255,  255,  255,  255,  256,  258,  258,  258,  259,
      261,  264,  267,  267,  267,  267,  267,  267,  267,  267,
      267,  267,  270,  273,  273,  273,  273,  273,  276,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      282,  282,  285,  286,  286,  287,  287,  287,  287,  287,
      287,  287,  288,  290,  290,  290,  290,  292,  292,  292,
      292,  293,  293,  293,  293,  294,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  298,
      298,  298,  298,  301,  301,  301,  304,  307,  307,  307,

      307,  307,  310,  310,  310,  310,  310,  310,  310,  310,
      310,  310,  310,  310,  313,  313,  313,  313,  313,  313,
      313,  314,  316,  316,  317,  319,  319,  319,  319,  320,
      322,  323,  325,  325,  325,  325,  325,  326,  328,  328,
      329,  331,  331,  331,  331,  331,  331,  331,  331,  332,
      334,  334,  335,  337,  337,  337,  340,  340,  343,  343,
      343,  346,  349,  349,  349,  352,  352,  355,  355,  355,
      355,  355,  355,  355,  358,  358,  361,  361,  361,  361,
      362,  363,  363,  363,  363,  363,  363,  363,  363,  363,
      363,  363,  363,  363,  363,  365,  367,  367,  368,  370,

      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  373,  376,  376,  379,  379,  379,  379,  379,  380,
      380,  380,  380,  380,  381,  383,  384,  386,  386,  387,
      388,  388,  388,  388,  388,  389,  391,  391,  392,  394,
      394,  394,  394,  394,  397,  400,  400,  400,  400,  403,
      403,  406,  406,  407,  408,  410,  410,  410,  410,  410,
      410,  411,  412,  414,  415,  417,  417,  417,  420,  420,
      420,  420,  423,  426,  426,  426,  426,  427,  429,  429,
      429,  429,  429,  430,  432,  432,  432,  435,  435,  438,
      439,  440,  442,  442,  442,  443,  443,  443,  446,  446,

      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  447,  447,  447,  449,  452,  452,  452,  452,
      453,  453
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    1,    6,    1,    1,    1,    1,
        1,    7,    7,    8,    9,    8,   10,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,    7,    1,   12,
       13,   14,    1,    1,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
        1,   16,    1,    1,   17,    1,   18,   19,   20,   21,

       22,   23,   24,   25,   26,   15,   27,   28,   29,   30,
       31,   32,   15,   33,   34,   35,   36,   37,   38,   39,
       40,   15,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[41] =
    {   0,
        1,    1,    2,    3,    4,    1,    1,    1,    5,    1,
        6,    7,    8,    9,    5,   10,   11,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5
    } ;

static yyconst flex_int16_t yy_base[938] =
    {   0,
        0,   13,   27,   44,   61,   77,    5,   92,   97,  108,
      113,  128, 1547,    0, 1548, 1548, 1548,   20,  144, 1548,
     1548, 1548,  102, 1548,  114,    0,    0, 1548,    0, 1548,
     1548,    0,    0,    0, 1548,  124, 1541,    0,    0,  133,
     1548, 1533,    0,    0,    0, 1548,  136, 1539,    0,  139,
      183, 1529,  187, 1548,    6,   56,  214,  215,  217,  218,
      216,  221,  227,  234,  220,   28,  222,  245,   58,  247,
      259,  249,  262,  278,    0,    0,    0,  262, 1548,    0,
      291, 1548, 1548,    0,  294, 1548,  281, 1548, 1522, 1505,
      249, 1518,  287,   55, 1502,  301,  298,  304, 1516, 1506,

     1500,  258, 1517,  305,  316,  325,  306,   88,  311,  331,
      327,  325,  338,  315,  343,  322,  344,  349,  346,  347,
      354,  355,  362,  356,  357,  367,  359,  368,  369,  370,
      371,  375,  373,  377,  381,  376,  378,  389,  383,  385,
      387,  399,  386,  401,  403,  404,  409,  406, 1499, 1498,
      403,  400, 1509, 1505, 1495, 1507, 1496, 1497, 1508, 1499,
     1493, 1497,  224, 1508, 1489, 1498, 1500, 1484, 1487, 1481,
     1480, 1475, 1482, 1491,  401, 1485, 1492, 1490,  405, 1479,
     1483, 1484, 1472, 1473, 1469,  419, 1476,  419,  416,  429,
      431,  432,  434,  433,  436,  439,  442,  441,  443,  444,

      452,  453,  445,  446,  454,  455,  469,  462,  463,  464,
      466,  469,  471,  474,  480,  476,  477,  481,  490,  482,
      483,  488,   93,  485,  493,  496,  497,  502,  503,  498,
      505,  508,  511,  513,  516,  518, 1475, 1465, 1479, 1467,
     1466,  515, 1478, 1460, 1461, 1463, 1474, 1456, 1461, 1460,
     1449, 1463, 1468, 1453, 1548, 1448, 1454, 1460, 1446, 1444,
     1457, 1446, 1448, 1452, 1449, 1440, 1455, 1442, 1436, 1442,
     1440, 1433, 1445, 1442, 1443, 1438, 1424, 1436, 1443, 1428,
     1431, 1423, 1436,  519,  521,  522,  524,  526,  531,  528,
      533,  549,  534,  540,  541,  542,  543, 1442,  556,  552,

      550,  554, 1424,  553,  569,  562,  575,  577,  566,  568,
      579,  572,  570,  573,  578,  584,  581,  588,  592,  593,
      604,  595,  598,  606,  599,  611,  602,  608,  609,  615,
      616,  617, 1423, 1422, 1425, 1417, 1417, 1418, 1430, 1411,
     1432, 1405, 1409, 1413, 1423, 1419, 1426, 1425, 1413, 1409,
     1418, 1400, 1420, 1405, 1418,  619, 1412, 1394, 1411, 1395,
     1396, 1400, 1392, 1405, 1387, 1400, 1395, 1406, 1386, 1390,
     1403, 1398, 1401, 1395, 1385, 1394, 1389, 1385, 1378,  620,
      621,  625,  618,  628,  635,  629,  632, 1404, 1548,  648,
      639,  642,  641,  653, 1548, 1403, 1548,  647,  650,  651,

     1376,  662, 1401, 1548, 1390, 1399, 1548, 1398, 1548,  655,
      654,  656,  657,  661,  664,  660,  666,  667, 1387,  669,
      674,  686,  677, 1396, 1548,  690,  681, 1395, 1548,  683,
     1394, 1548,  682,  684,  685,  705, 1383,  697, 1366, 1365,
     1375, 1371, 1373, 1372, 1360, 1361, 1548, 1374, 1368, 1365,
     1349, 1370, 1548, 1548, 1348, 1360, 1348, 1366, 1548, 1365,
     1548, 1548, 1360, 1342, 1345, 1340, 1342, 1351,  698, 1337,
     1353, 1334, 1335, 1354, 1337, 1548, 1352, 1343, 1548, 1345,
     1548, 1335, 1340, 1328, 1346, 1345, 1320,  709,  710,  701,
      706,  702,  711,  707,  708, 1353, 1548,  713,  712,  715,

        0, 1548, 1342,  726,  719, 1334,  732, 1548, 1548,  727,
      731,  717,  742,  743,  735, 1548,  737,  738,  740, 1548,
      744,  747, 1350, 1548,  745, 1349, 1548,  748,  754,  756,
      767,  758,  770, 1548,  773, 1338, 1337, 1319, 1316, 1312,
     1316, 1325, 1310, 1548, 1313, 1321, 1307, 1548, 1327, 1326,
     1321, 1548, 1548, 1305, 1315, 1305, 1321, 1320, 1299, 1548,
     1296, 1305, 1295, 1294, 1309, 1548, 1309, 1548, 1307, 1297,
     1302, 1309, 1304, 1548, 1548, 1307, 1316, 1548,  787, 1548,
      766,  779,  751,  770,  781, 1305,  774,  775,  780, 1304,
     1548, 1313, 1548,  784, 1290, 1311, 1288,  788,  782,  783,

     1290, 1548, 1308, 1548,  787,  785,  789,  792,  790,  810,
      802,  800,  815, 1297, 1306, 1548,  808, 1278, 1304, 1548,
     1548, 1548, 1268, 1292, 1270, 1265, 1289, 1288, 1262, 1267,
     1264, 1548, 1548, 1263, 1283, 1267, 1268, 1548, 1548, 1260,
     1258, 1255, 1260, 1255, 1271, 1260, 1251, 1264, 1271, 1548,
     1249, 1548,  827,  828, 1548,  829,  831,  835,  841,  842,
      845, 1279, 1548,  836,  847,  834, 1548,  853,  856,  842,
     1548,  844, 1247, 1253, 1276, 1548,  858,  870, 1253,  862,
      851,  863,  864,  849,  865,  879,  873,  885, 1548,  874,
     1248, 1263, 1548, 1241,  880, 1548, 1548, 1261, 1260, 1242,

     1241, 1548,  876, 1257, 1251, 1234, 1246, 1234, 1235, 1232,
     1250, 1228, 1248, 1548, 1230,  887,  891,  899,  907,  903,
     1256, 1548,  887, 1255, 1548,  892,  909, 1224, 1253, 1548,
     1252, 1548,  895,  900, 1229, 1232, 1249, 1548,  910, 1248,
     1548, 1223,  912,  913, 1236, 1235,  915,  924, 1244, 1548,
      920, 1243, 1548,  921, 1225, 1548, 1214, 1548, 1214, 1221,
     1548, 1548, 1212, 1208, 1548, 1218, 1548, 1221, 1207, 1223,
     1222, 1205, 1220, 1548, 1198, 1548, 1199,  936,  935, 1548,
     1548,  937,  922,  928,  929, 1197,  943,  955, 1199,  956,
      932, 1207,  939,  944, 1548, 1548,  957, 1224, 1548,  948,

      961, 1201, 1196, 1190, 1185, 1209, 1208, 1189, 1187, 1189,
     1548, 1548, 1204, 1548, 1186, 1202,  969,  972, 1548,  973,
      964,  966, 1189, 1210, 1548, 1209, 1548, 1182, 1207, 1548,
      970, 1196,  979,  985, 1205, 1548,  976, 1204, 1548, 1172,
     1192, 1171, 1168, 1548, 1548, 1183, 1186, 1184, 1548, 1164,
     1548,  990, 1548, 1173, 1548,  952,  991, 1149,  994,  967,
     1548, 1163, 1548, 1150, 1548,  998, 1125, 1548, 1108, 1129,
     1107, 1548, 1548, 1120, 1000, 1005, 1125, 1548, 1098, 1004,
     1006, 1002, 1123, 1548, 1095, 1108, 1548, 1101, 1548, 1548,
     1110, 1548, 1013, 1017, 1548, 1001, 1009, 1548,  996,  974,

     1009, 1020,  865,  804, 1011, 1022, 1023,  237,  198,  177,
     1025, 1548,  134, 1028, 1548, 1548, 1030, 1033, 1041, 1548,
     1548, 1046, 1057, 1068, 1079, 1090, 1101, 1112,    8, 1119,
     1130, 1141, 1152, 1163, 1174, 1185, 1194
    } ;

static yyconst flex_int16_t yy_def[938] =
    {   0,
      922,  922,  923,  923,  924,  924,  925,  925,  926,  926,
      927,  927,  921,  928,  921,  921,  921,  928,  921,  921,
      921,  921,  921,  921,  921,  929,  929,  921,  930,  921,
      921,  931,  931,  931,  921,  931,  921,  932,  932,  932,
      921,  933,  934,  934,  934,  921,  934,  921,  928,  928,
      921,  935,  921,  921,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  921,  929,  930,  931,  931,  921,  932,
      932,  921,  921,  934,  934,  921,   53,  921,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,

       87,   87,   87,   87,   87,   87,   87,  935,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,

      935,  935,  935,  935,  935,  935,  921,  935,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  935,  935,  935,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,  921,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,  935,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,

      935,  935,  921,  935,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,
      935,  935,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,  935,
      935,  935,  935,  935,  935,  935,  935,  921,  921,  935,
      935,  935,  935,  935,  921,  921,  921,  935,  935,  935,

      921,  935,  921,  921,  935,  921,  921,  921,  921,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  921,  921,  935,  935,  921,  921,  935,
      921,  921,  935,  935,  935,  935,  935,  935,   87,   87,
       87,   87,   87,   87,   87,   87,  921,   87,   87,   87,
       87,   87,  921,  921,   87,   87,   87,   87,  921,   87,
      921,  921,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,  921,   87,   87,  921,   87,
      921,   87,   87,   87,   87,   87,   87,  935,  935,  935,
      935,  935,  935,  935,  935,  921,  921,  935,  935,  935,

      936,  921,  935,  935,  935,  921,  921,  921,  921,  935,
      935,  935,  935,  935,  935,  921,  935,  935,  935,  921,
      935,  935,  921,  921,  935,  921,  921,  935,  935,  935,
      935,  935,  921,  921,  935,   87,   87,   87,   87,   87,
       87,   87,   87,  921,   87,   87,   87,  921,   87,   87,
       87,  921,  921,   87,   87,   87,   87,   87,   87,  921,
       87,   87,   87,   87,   87,  921,   87,  921,   87,   87,
       87,   87,   87,  921,  921,   87,  921,  921,  937,  921,
      935,  935,  935,  935,  935,  935,  935,  935,  935,  936,
      921,  921,  921,  935,  921,  921,  921,  935,  935,  935,

      921,  921,  921,  921,  935,  935,  935,  935,  935,  935,
      935,  935,  935,  935,  921,  921,  935,  921,  921,  921,
      921,  921,   87,   87,   87,   87,   87,   87,   87,   87,
       87,  921,  921,   87,   87,   87,   87,  921,  921,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,  921,
       87,  921,  937,  937,  921,  937,  937,  937,  937,  937,
      935,  921,  921,  935,  935,  921,  921,  935,  935,  935,
      921,  935,  921,  921,  921,  921,  935,  935,  921,  935,
      935,  935,  935,  935,  935,  935,  935,  935,  921,  935,
      921,   87,  921,   87,   87,  921,  921,   87,   87,   87,

       87,  921,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,  921,   87,  937,  937,  937,  937,  937,
      921,  921,  935,  921,  921,  935,  935,  921,  921,  921,
      921,  921,  935,  935,  921,  921,  921,  921,  935,  921,
      921,  921,  935,  935,  935,  935,  935,  935,  921,  921,
      935,  921,  921,  935,  921,  921,   87,  921,   87,   87,
      921,  921,   87,   87,  921,   87,  921,   87,   87,   87,
       87,   87,   87,  921,   87,  921,   87,  937,  937,  921,
      921,  937,  935,  935,  935,  921,  935,  935,  921,  921,
      935,  921,  935,  935,  921,  921,  935,  921,  921,  935,

      935,  921,   87,   87,   87,   87,   87,   87,   87,   87,
      921,  921,   87,  921,   87,   87,  937,  937,  921,  935,
      935,  935,  921,  921,  921,  921,  921,  921,  921,  921,
      935,  921,  935,  935,  921,  921,  935,  921,  921,  921,
       87,   87,   87,  921,  921,   87,   87,   87,  921,   87,
      921,  937,  921,  921,  921,  935,  935,  921,  921,  935,
      921,  921,  921,  921,  921,  935,  921,  921,   87,   87,
       87,  921,  921,   87,  937,  935,  921,  921,  921,  921,
      921,  935,  921,  921,  921,   87,  921,   87,  921,  921,
      921,  921,  921,  921,  921,  935,  921,  921,   87,  921,

      935,  921,   87,  921,  935,  921,  921,   87,  921,  935,
      921,  921,   87,  921,  921,  921,  921,  921,  921,  921,
        0,  921,  921,  921,  921,  921,  921,  921,  921,  921,
      921,  921,  921,  921,  921,  921,  921
    } ;

static yyconst flex_int16_t yy_nxt[1589] =
    {   0,
      921,   15,   16,   15,   17,   18,   33,   34,   33,   35,
       36,   19,   75,   20,   15,   16,   15,   17,   18,   54,
       37,   50,   51,   50,   19,  108,   20,   21,   15,   16,
       15,   22,   23,   24,   25,   26,   24,   25,   24,   24,
       24,   54,   21,   21,   21,   15,   16,   15,   22,   23,
       24,   25,   26,   24,   25,   24,   24,   24,  129,   21,
       21,   21,   15,   16,   15,   28,   23,   21,   21,   54,
       21,   54,   21,   30,   31,  133,   21,   21,   15,   16,
       15,   28,   23,   21,   21,  158,   21,  159,   21,   30,
       31,  109,   21,   33,   34,   33,   35,   36,   39,   16,

       39,   54,   40,   51,   51,   51,   54,   37,   41,   39,
       16,   39,   42,   40,   44,   45,   44,   46,   47,   41,
      319,   74,  189,   42,   74,   78,   78,   78,   48,   44,
       45,   44,   46,   47,   81,   51,   81,   85,   85,   85,
       50,   51,   50,   48,   52,   52,   52,  916,   52,   52,
       52,   52,   52,   53,   52,   52,   52,   54,   52,   52,
       52,   55,   56,   57,   58,   59,   60,   61,   62,   63,
       52,   64,   65,   66,   67,   68,   69,   70,   71,   52,
       72,   73,   52,   52,   51,   51,   51,   87,   87,   87,
      915,   87,   87,   87,   87,   87,   87,   87,   87,   87,

       88,   87,   87,   87,   89,   90,   91,   92,   93,   94,
       95,   96,   97,   87,   98,   99,  100,  101,  102,  103,
      104,  105,   87,  106,  107,   87,   87,   54,   54,   54,
       54,   54,  914,   54,   54,   54,  112,  113,  110,  120,
       54,  128,  121,  253,  111,  254,  114,   54,  117,  123,
      118,  126,  119,  115,  122,  116,  124,  130,   54,  127,
       54,  125,   54,   78,   78,   78,  143,  144,  134,  913,
      131,  135,   54,  151,  145,   54,  138,  132,  136,  152,
      139,  137,  146,  172,  140,   74,  147,  148,   74,  141,
      173,  142,   81,   51,   81,   85,   85,   85,   87,   87,

       87,   87,   87,   87,   87,   87,   87,  154,   87,   87,
       87,   87,   87,   87,   87,   87,  155,   87,   87,  161,
      164,  167,  162,  156,   54,  157,  175,  165,   54,  168,
      187,  188,  166,  178,  163,   54,  176,  179,   54,  177,
       54,  180,  183,  184,   54,  190,  181,  195,  182,  197,
      185,   54,  191,  199,  193,  194,   54,   54,  186,   54,
       54,  192,   54,  196,  198,  207,  201,   54,   54,   54,
       54,  202,   54,  200,  205,   54,  206,  203,  209,  204,
       54,   54,   54,   54,   54,  210,   54,  208,   54,   54,
       54,   54,  211,  217,   54,  222,   54,  212,   54,   54,

       54,  221,   54,  213,  214,  216,  218,  223,  219,  215,
      227,  220,   54,  226,   54,  224,   54,   54,  229,   54,
      228,  225,   54,  232,  239,  233,  235,  241,  242,   54,
      266,  230,  267,  240,  234,  236,  231,  271,  279,  282,
      280,  284,   54,  272,   54,   54,   54,   54,  283,   54,
      286,  289,   54,  291,   54,   54,   54,   54,   54,   54,
      295,  290,  287,  285,  288,   54,   54,   54,   54,  300,
      294,  301,  207,  292,  293,   54,   54,   54,  296,   54,
      297,  298,   54,  299,   54,  306,  302,   54,  303,   54,
       54,  305,  309,   54,   54,   54,   54,  304,   54,  312,

      307,   54,  313,   54,  308,  310,   54,  315,  311,   54,
       54,   54,  317,  320,  314,   54,   54,  322,   54,  316,
      323,   54,  318,  324,   54,  328,   54,  321,  325,   54,
      327,   54,   54,  338,   54,   54,  326,   54,  332,   54,
      330,   54,  329,  339,   54,  386,   54,   54,  382,  380,
      331,  381,  388,   54,   54,   54,   54,  383,  384,  396,
      393,  385,  389,   54,  394,   54,   54,   54,  387,  397,
      392,  400,  403,  390,  391,   54,  398,  399,  406,   54,
      408,   54,  404,   54,  412,   54,   54,  402,  407,  405,
      409,   54,   54,  419,   54,  410,  414,   54,  417,  420,

      416,   54,  411,  413,  415,   54,   54,  424,   54,  428,
      418,   54,   54,  422,  431,   54,  430,  425,  423,  429,
      433,   54,   54,  421,  432,  427,  435,  426,   54,   54,
       54,   54,  462,   54,   54,  434,  436,  463,   54,  491,
      437,   54,   54,  490,  464,   54,  492,  438,   54,  488,
      489,  496,   54,  493,   54,   54,  501,  498,  494,  495,
       54,  497,  499,   54,   54,  507,  502,   54,   54,   54,
       54,  504,  510,  516,   54,  508,  500,   54,  517,   54,
       54,  503,   54,  505,  519,  515,  512,   54,  511,  523,
       54,  513,  514,  526,   54,   54,   54,   54,   54,  524,

      518,  529,  528,  527,  521,  531,  525,  522,  533,  530,
       54,  560,  577,  579,   54,   54,  561,  532,   54,   54,
       54,   54,  578,  580,   54,   54,   54,  585,   54,  592,
       54,  581,   54,  588,  535,  596,  594,  583,  582,  593,
       54,  584,  586,  587,   54,  601,  603,  600,   54,  589,
       54,   54,  599,   54,  597,  602,  604,   54,   54,  598,
       54,   54,  611,  607,   54,  610,  612,   54,  605,   54,
      615,   54,  606,  533,  608,  617,  619,  614,  609,   54,
      616,  613,  662,   54,  666,  664,  620,   54,   54,  618,
      653,  675,  663,   54,   54,   54,   54,   54,   54,  655,

       54,  676,   54,   54,  661,   54,  656,  669,  665,  678,
      677,  657,  668,   54,  670,   54,  658,  659,  672,  681,
      680,   54,  683,   54,  684,  682,  660,  685,   54,  686,
      653,  921,  921,  909,  921,  687,  688,  666,  921,  655,
      655,  655,  690,  655,  921,  921,  716,  655,  721,   54,
      724,  728,  717,  655,  655,   54,  729,   54,  722,  731,
      725,  737,   54,  720,   54,  718,  730,  719,  726,  732,
      723,  738,  733,  740,  734,   54,   54,   54,   54,  747,
      743,  727,  749,  741,  745,  744,   54,   54,  752,  765,
      921,  739,  750,  758,  921,  908,  746,  748,  753,  655,

       54,  759,  921,  655,  754,   54,  921,  751,   54,  766,
      921,  655,  780,   54,  760,  655,  778,  783,  779,  655,
      781,  784,   54,   54,  787,   54,   54,  798,   54,  793,
      785,  791,  788,   54,   54,   54,  782,  799,  921,  921,
      921,   54,   54,  794,  797,   54,  824,  655,  655,  655,
      819,  820,   54,  801,  800,  817,  825,   54,  826,  829,
      835,   54,  821,  831,  838,   54,  818,  822,  827,  830,
      836,  833,  921,  834,  839,  921,  854,   54,  837,   54,
       54,  655,  862,   54,  655,  853,  855,  860,  864,   54,
      852,  876,  863,  921,  877,  904,  856,  880,  865,  882,

      857,  883,  655,  921,  878,  866,  881,  880,  891,  894,
      895,  884,  655,  890,   54,   54,  881,  875,  892,  896,
      894,  895,   54,  906,   54,  906,  911,  912,  911,  912,
      903,  917,  907,  917,  907,  901,  919,  920,  902,  905,
      918,  900,  918,  910,  919,  920,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       38,   38,   38,   38,   38,   38,   38,   38,   38,   38,

       38,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   49,  891,   49,   49,   49,   49,  899,   49,
       49,  898,   49,   76,   76,  897,  883,  893,  877,   76,
       77,   77,   77,  889,   77,   77,   77,   77,   77,  888,
       77,   80,  887,   80,   80,   80,   80,  886,   80,   80,
      885,   80,   82,  864,   82,   82,   82,   82,   82,   82,
       82,   82,   82,   84,   84,   84,  862,   84,   84,   84,
       84,   84,  879,   84,   52,   52,  854,   52,   52,   52,
       52,   52,   52,   52,   52,  590,  590,  590,  590,  590,
      590,  590,  590,  874,  590,  590,  654,  873,  654,  872,

      871,  654,  870,  869,  654,  868,  867,  838,  835,  861,
      829,  859,  826,  824,  858,  851,  850,  849,  848,  847,
      846,  845,  844,  843,  842,  841,  840,  798,  832,  828,
      823,  816,  815,  814,  813,  812,  811,  810,  809,  808,
      807,  806,  805,  804,  803,  802,  752,  749,  796,  795,
      792,  740,  737,  790,  789,  731,  729,  786,  724,  721,
      777,  776,  775,  774,  773,  772,  771,  770,  769,  768,
      767,  764,  763,  762,  761,  757,  756,  755,  742,  675,
      736,  735,  662,  715,  714,  713,  712,  711,  710,  709,
      708,  707,  706,  705,  704,  703,  702,  701,  700,  699,

      698,  697,  696,  695,  694,  693,  692,  619,  691,  615,
      689,  603,  679,  674,  596,  673,  592,  671,  667,  577,
      652,  651,  650,  649,  648,  647,  646,  645,  644,  643,
      642,  641,  640,  639,  638,  637,  636,  635,  634,  633,
      632,  631,  630,  629,  628,  627,  626,  625,  624,  623,
      622,  621,  526,  523,  595,  591,  496,  576,  575,  574,
      573,  572,  571,  570,  569,  568,  567,  566,  565,  564,
      563,  562,  559,  558,  557,  556,  555,  554,  553,  552,
      551,  550,  549,  548,  547,  546,  545,  544,  543,  542,
      541,  540,  539,  538,  537,  536,  534,  431,  428,  424,

      520,  408,  406,  509,  403,  506,  396,  388,  487,  486,
      485,  484,  483,  482,  481,  480,  479,  478,  477,  476,
      475,  474,  473,  472,  471,  470,  469,  468,  467,  466,
      465,  461,  460,  459,  458,  457,  456,  455,  454,  453,
      452,  451,  450,  449,  448,  447,  446,  445,  444,  443,
      442,  441,  440,  439,  401,  395,  379,  378,  377,  376,
      375,  374,  373,  372,  371,  370,  369,  368,  367,  366,
      365,  364,  363,  362,  361,  360,  359,  358,  357,  356,
      355,  354,  353,  352,  351,  350,  349,  348,  347,  346,
      345,  344,  343,  342,  341,  340,  337,  336,  335,  334,

      333,  281,  278,  277,  276,  275,  274,  273,  270,  269,
      268,  265,  264,  263,  262,  261,  260,  259,  258,  257,
      256,  255,  252,  251,  250,  249,  248,  247,  246,  245,
      244,  243,  238,  237,  174,  171,  170,  169,  160,  153,
      150,  149,   54,   86,   83,   79,  921,   13,  921,  921,
      921,  921,  921,  921,  921,  921,  921,  921,  921,  921,
      921,  921,  921,  921,  921,  921,  921,  921,  921,  921,
      921,  921,  921,  921,  921,  921,  921,  921,  921,  921,
      921,  921,  921,  921,  921,  921,  921,  921
    } ;

static yyconst flex_int16_t yy_chk[1589] =
    {   0,
        0,    1,    1,    1,    1,    1,    7,    7,    7,    7,
        7,    1,  929,    1,    2,    2,    2,    2,    2,   55,
        7,   18,   18,   18,    2,   55,    2,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,   66,    3,    3,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,   66,    4,
        4,    5,    5,    5,    5,    5,    5,    5,    5,   56,
        5,   69,    5,    5,    5,   69,    5,    6,    6,    6,
        6,    6,    6,    6,    6,   94,    6,   94,    6,    6,
        6,   56,    6,    8,    8,    8,    8,    8,    9,    9,

        9,  108,    9,   23,   23,   23,  223,    8,    9,   10,
       10,   10,    9,   10,   11,   11,   11,   11,   11,   10,
      223,   25,  108,   10,   25,   36,   36,   36,   11,   12,
       12,   12,   12,   12,   40,   40,   40,   47,   47,   47,
       50,   50,   50,   12,   19,   19,   19,  913,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   51,   51,   51,   53,   53,   53,
      910,   53,   53,   53,   53,   53,   53,   53,   53,   53,

       53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   57,   58,   61,
       59,   60,  909,   65,   62,   67,   58,   59,   57,   62,
       63,   65,   62,  163,   57,  163,   59,   64,   60,   63,
       60,   64,   61,   59,   62,   59,   63,   67,   68,   64,
       70,   63,   72,   78,   78,   78,   72,   72,   70,  908,
       68,   70,   71,   91,   72,   73,   71,   68,   70,   91,
       71,   70,   72,  102,   71,   74,   73,   73,   74,   71,
      102,   71,   81,   81,   81,   85,   85,   85,   87,   87,

       87,   87,   87,   87,   87,   87,   87,   93,   87,   87,
       87,   87,   87,   87,   87,   87,   93,   87,   87,   96,
       97,   98,   96,   93,  109,   93,  104,   97,  114,   98,
      107,  107,   97,  105,   96,  116,  104,  105,  112,  104,
      111,  105,  106,  106,  110,  109,  105,  112,  105,  114,
      106,  113,  110,  116,  111,  111,  115,  117,  106,  119,
      120,  110,  118,  113,  115,  123,  118,  121,  122,  124,
      125,  119,  127,  117,  122,  123,  122,  120,  125,  121,
      126,  128,  129,  130,  131,  126,  133,  124,  132,  136,
      134,  137,  127,  133,  135,  137,  139,  128,  140,  143,

      141,  136,  138,  129,  130,  132,  134,  138,  134,  131,
      141,  135,  142,  140,  144,  139,  145,  146,  143,  148,
      142,  139,  147,  146,  151,  146,  148,  152,  152,  189,
      175,  144,  175,  151,  147,  148,  145,  179,  186,  188,
      186,  189,  190,  179,  191,  192,  194,  193,  188,  195,
      191,  194,  196,  195,  198,  197,  199,  200,  203,  204,
      199,  194,  192,  190,  193,  201,  202,  205,  206,  204,
      198,  205,  207,  196,  197,  208,  209,  210,  200,  211,
      201,  202,  212,  203,  213,  210,  206,  214,  207,  216,
      217,  209,  213,  215,  218,  220,  221,  208,  224,  216,

      211,  222,  217,  219,  212,  214,  225,  219,  215,  226,
      227,  230,  221,  224,  218,  228,  229,  226,  231,  220,
      227,  232,  222,  228,  233,  232,  234,  225,  229,  235,
      231,  236,  284,  242,  285,  286,  230,  287,  236,  288,
      234,  290,  233,  242,  289,  290,  291,  293,  286,  284,
      235,  285,  292,  294,  295,  296,  297,  287,  288,  299,
      296,  289,  292,  301,  297,  300,  304,  302,  291,  299,
      295,  302,  305,  293,  294,  306,  300,  301,  307,  309,
      308,  310,  305,  313,  309,  312,  314,  304,  307,  306,
      308,  315,  311,  316,  317,  308,  311,  316,  314,  317,

      313,  318,  308,  310,  312,  319,  320,  321,  322,  324,
      315,  323,  325,  319,  326,  327,  325,  321,  320,  324,
      327,  328,  329,  318,  326,  323,  329,  322,  330,  331,
      332,  383,  356,  380,  381,  328,  330,  356,  382,  383,
      331,  384,  386,  382,  356,  387,  384,  332,  385,  380,
      381,  390,  391,  385,  393,  392,  394,  391,  386,  387,
      398,  390,  392,  399,  400,  402,  394,  411,  410,  412,
      413,  399,  410,  416,  414,  402,  393,  415,  416,  417,
      418,  398,  420,  400,  418,  415,  412,  421,  411,  422,
      423,  413,  414,  426,  427,  433,  430,  434,  435,  422,

      417,  430,  427,  426,  420,  434,  423,  421,  436,  433,
      438,  469,  488,  489,  490,  492,  469,  435,  436,  491,
      494,  495,  488,  489,  493,  499,  498,  494,  500,  504,
      512,  490,  505,  499,  438,  507,  505,  492,  491,  504,
      510,  493,  495,  498,  511,  513,  514,  512,  515,  500,
      517,  518,  511,  519,  507,  513,  514,  521,  525,  510,
      522,  528,  525,  518,  583,  522,  528,  529,  515,  530,
      531,  532,  517,  533,  519,  532,  535,  530,  521,  581,
      531,  529,  582,  584,  585,  583,  535,  587,  588,  533,
      579,  598,  582,  589,  585,  599,  600,  594,  606,  579,

      605,  598,  607,  609,  581,  608,  579,  588,  584,  600,
      599,  579,  587,  612,  589,  611,  579,  579,  594,  606,
      605,  617,  608,  610,  609,  607,  579,  610,  613,  611,
      653,  654,  656,  904,  657,  612,  613,  666,  658,  653,
      654,  656,  617,  657,  659,  660,  656,  658,  661,  664,
      665,  666,  657,  659,  660,  670,  668,  672,  661,  669,
      665,  677,  684,  660,  681,  658,  668,  659,  665,  669,
      664,  677,  670,  678,  672,  680,  682,  683,  685,  684,
      680,  665,  686,  678,  682,  681,  687,  690,  688,  703,
      716,  677,  686,  695,  717,  903,  683,  685,  688,  716,

      723,  695,  718,  717,  690,  726,  720,  687,  733,  703,
      719,  718,  718,  734,  695,  720,  716,  723,  717,  719,
      719,  726,  727,  739,  733,  743,  744,  748,  747,  743,
      727,  739,  734,  751,  754,  783,  720,  748,  779,  778,
      782,  784,  785,  744,  747,  791,  787,  779,  778,  782,
      782,  783,  793,  754,  751,  778,  787,  794,  788,  790,
      797,  800,  784,  791,  801,  856,  779,  785,  788,  790,
      797,  793,  817,  794,  801,  818,  820,  821,  800,  822,
      860,  817,  833,  831,  818,  818,  820,  831,  834,  837,
      817,  856,  833,  852,  857,  900,  821,  859,  834,  860,

      822,  866,  852,  875,  857,  837,  859,  880,  876,  881,
      881,  866,  875,  875,  896,  882,  880,  852,  876,  882,
      894,  894,  901,  902,  905,  906,  907,  907,  911,  911,
      899,  914,  902,  917,  906,  896,  918,  918,  897,  901,
      914,  893,  917,  905,  919,  919,  922,  922,  922,  922,
      922,  922,  922,  922,  922,  922,  922,  923,  923,  923,
      923,  923,  923,  923,  923,  923,  923,  923,  924,  924,
      924,  924,  924,  924,  924,  924,  924,  924,  924,  925,
      925,  925,  925,  925,  925,  925,  925,  925,  925,  925,
      926,  926,  926,  926,  926,  926,  926,  926,  926,  926,

      926,  927,  927,  927,  927,  927,  927,  927,  927,  927,
      927,  927,  928,  891,  928,  928,  928,  928,  888,  928,
      928,  886,  928,  930,  930,  885,  883,  879,  877,  930,
      931,  931,  931,  874,  931,  931,  931,  931,  931,  871,
      931,  932,  870,  932,  932,  932,  932,  869,  932,  932,
      867,  932,  933,  864,  933,  933,  933,  933,  933,  933,
      933,  933,  933,  934,  934,  934,  862,  934,  934,  934,
      934,  934,  858,  934,  935,  935,  854,  935,  935,  935,
      935,  935,  935,  935,  935,  936,  936,  936,  936,  936,
      936,  936,  936,  850,  936,  936,  937,  848,  937,  847,

      846,  937,  843,  842,  937,  841,  840,  838,  835,  832,
      829,  828,  826,  824,  823,  816,  815,  813,  810,  809,
      808,  807,  806,  805,  804,  803,  802,  798,  792,  789,
      786,  777,  775,  773,  772,  771,  770,  769,  768,  766,
      764,  763,  760,  759,  757,  755,  752,  749,  746,  745,
      742,  740,  737,  736,  735,  731,  729,  728,  724,  721,
      715,  713,  712,  711,  710,  709,  708,  707,  706,  705,
      704,  701,  700,  699,  698,  694,  692,  691,  679,  675,
      674,  673,  662,  651,  649,  648,  647,  646,  645,  644,
      643,  642,  641,  640,  637,  636,  635,  634,  631,  630,

      629,  628,  627,  626,  625,  624,  623,  619,  618,  615,
      614,  603,  601,  597,  596,  595,  592,  590,  586,  577,
      576,  573,  572,  571,  570,  569,  567,  565,  564,  563,
      562,  561,  559,  558,  557,  556,  555,  554,  551,  550,
      549,  547,  546,  545,  543,  542,  541,  540,  539,  538,
      537,  536,  526,  523,  506,  503,  496,  487,  486,  485,
      484,  483,  482,  480,  478,  477,  475,  474,  473,  472,
      471,  470,  468,  467,  466,  465,  464,  463,  460,  458,
      457,  456,  455,  452,  451,  450,  449,  448,  446,  445,
      444,  443,  442,  441,  440,  439,  437,  431,  428,  424,

      419,  408,  406,  405,  403,  401,  396,  388,  379,  378,
      377,  376,  375,  374,  373,  372,  371,  370,  369,  368,
      367,  366,  365,  364,  363,  362,  361,  360,  359,  358,
      357,  355,  354,  353,  352,  351,  350,  349,  348,  347,
      346,  345,  344,  343,  342,  341,  340,  339,  338,  337,
      336,  335,  334,  333,  303,  298,  283,  282,  281,  280,
      279,  278,  277,  276,  275,  274,  273,  272,  271,  270,
      269,  268,  267,  266,  265,  264,  263,  262,  261,  260,
      259,  258,  257,  256,  254,  253,  252,  251,  250,  249,
      248,  247,  246,  245,  244,  243,  241,  240,  239,  238,

      237,  187,  185,  184,  183,  182,  181,  180,  178,  177,
      176,  174,  173,  172,  171,  170,  169,  168,  167,  166,
      165,  164,  162,  161,  160,  159,  158,  157,  156,  155,
      154,  153,  150,  149,  103,  101,  100,   99,   95,   92,
       90,   89,   52,   48,   42,   37,   13,  921,  921,  921,
      921,  921,  921,  921,  921,  921,  921,  921,  921,  921,
      921,  921,  921,  921,  921,  921,  921,  921,  921,  921,
      921,  921,  921,  921,  921,  921,  921,  921,  921,  921,
      921,  921,  921,  921,  921,  921,  921,  921
    } ;

extern int gtkdialog__flex_debug;
int gtkdialog__flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up gtkdialog_text */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = (yy_full_lp); /* restore orig. accepting pos. */ \
(yy_state_ptr) = (yy_full_state); /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

static int yy_more_flag = 0;
static int yy_more_len = 0;
#define yymore() ((yy_more_flag) = 1)
#define YY_MORE_ADJ (yy_more_len)
#define YY_RESTORE_YY_MORE_OFFSET
char *gtkdialog_text;
#line 1 "gtkdialog_lexer.l"
#line 2 "gtkdialog_lexer.l"
/*
 * gtkdialog_lexer.l:
 * Gtkdialog - A small utility for fast and easy GUI building.
 * Copyright (C) 2003-2007  László Pere <pipas@linux.pte.hu>
 * Copyright (C) 2011-2012  Thunor <thunorsif@hotmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

/*
**
** $Id: lexer.l,v 1.2 2004/11/20 20:01:25 root Exp root $
** $Log: lexer.l,v $
** Revision 1.2  2004/11/20 20:01:25  root
** - Log entries.
**
*/

#define YY_INPUT(buf,result,max_size) \
    { \
    int c = getnextchar(); \
    result = (c == EOF) ? YY_NULL : (buf[0] = c, 1); \
    }


#include <string.h>
#include <gtk/gtk.h>

#include "gtkdialog.h"
#include "attributes.h"
#include "gtkdialog_parser.h"

static gchar *process_string(gchar *str);

extern int linenumber;
gchar *Token;

/**************************************************************
* Thunor: Uncomment this to debug.
**************************************************************
* %option debug */



#line 1249 "gtkdialog_lexer.c"

#define INITIAL 0
#define EMBEDDED 1
#define ST_TAG_ATTR 2
#define ST_QUOTED_TAGATTR 3
#define ST_STRING 4
#define ST_QUOTED_STRING 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int gtkdialog_lex_destroy (void );

int gtkdialog_get_debug (void );

void gtkdialog_set_debug (int debug_flag  );

YY_EXTRA_TYPE gtkdialog_get_extra (void );

void gtkdialog_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *gtkdialog_get_in (void );

void gtkdialog_set_in  (FILE * in_str  );

FILE *gtkdialog_get_out (void );

void gtkdialog_set_out  (FILE * out_str  );

int gtkdialog_get_leng (void );

char *gtkdialog_get_text (void );

int gtkdialog_get_lineno (void );

void gtkdialog_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int gtkdialog_wrap (void );
#else
extern int gtkdialog_wrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( gtkdialog_text, gtkdialog_leng, 1, gtkdialog_out )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( gtkdialog_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( gtkdialog_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, gtkdialog_in))==0 && ferror(gtkdialog_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(gtkdialog_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int gtkdialog_lex (void);

#define YY_DECL int gtkdialog_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after gtkdialog_text and gtkdialog_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 62 "gtkdialog_lexer.l"


	#ifdef DEBUG
		g_message("%s(): Start", __func__);
	#endif

#line 1443 "gtkdialog_lexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)gtkdialog_alloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in gtkdialog_lex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! gtkdialog_in )
			gtkdialog_in = stdin;

		if ( ! gtkdialog_out )
			gtkdialog_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			gtkdialog_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				gtkdialog__create_buffer(gtkdialog_in,YY_BUF_SIZE );
		}

		gtkdialog__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		(yy_more_len) = 0;
		if ( (yy_more_flag) )
			{
			(yy_more_len) = (yy_c_buf_p) - (yytext_ptr);
			(yy_more_flag) = 0;
			}
		yy_cp = (yy_c_buf_p);

		/* Support of gtkdialog_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 922 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1548 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     (yy_looking_for_trail_begin) )
					{
					if ( yy_act == (yy_looking_for_trail_begin) )
						{
						(yy_looking_for_trail_begin) = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					(yy_looking_for_trail_begin) = yy_act & ~YY_TRAILING_MASK;
					(yy_looking_for_trail_begin) |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
#line 68 "gtkdialog_lexer.l"
{ Token=">"; return(gtkdialog_text[0]); 			}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 69 "gtkdialog_lexer.l"
{ Token="indent chars"; 				}
	YY_BREAK
/*
	 * Attributes.
	 */
case 3:
YY_RULE_SETUP
#line 74 "gtkdialog_lexer.l"
{
	#ifdef DEBUG 
	g_message(" -> TAG_ATTR_NAME: '%s'", gtkdialog_text);
	#endif
	Token="tag attribute name";
	gtkdialog_lval.cval=strdup(gtkdialog_text);
	return TAG_ATTR_NAME;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 84 "gtkdialog_lexer.l"
{
					  #ifdef DEBUG 
					  g_message(" -> spec char: '%s'", gtkdialog_text);
					  #endif
					  Token="=";
					  return '=';
												}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 91 "gtkdialog_lexer.l"
{
					  #ifdef DEBUG 
					  g_message(" -> spec char: '%s'", gtkdialog_text);
					  #endif
					  Token=">";
					  BEGIN(0);
					  return '>';
												}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 100 "gtkdialog_lexer.l"
{
					  Token = "double quote";
					  BEGIN(ST_QUOTED_TAGATTR);				}
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 104 "gtkdialog_lexer.l"
{
					  Token = "string";
					  yymore();						}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 108 "gtkdialog_lexer.l"
{
					  Token = "string";
					  yymore();						}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 112 "gtkdialog_lexer.l"
{
					  Token = gtkdialog_text;
					  gtkdialog_lval.cval = g_strdup(gtkdialog_text);
					  gtkdialog_lval.cval[strlen(gtkdialog_lval.cval) - 1] = '\0';
					  BEGIN(ST_TAG_ATTR);
					  return STRING;
					  							}
	YY_BREAK
/*
	 * The elements of the embedded imperative language.
	 */
case 10:
YY_RULE_SETUP
#line 128 "gtkdialog_lexer.l"
{ 
	Token="<show/>"; 
	return SHOW_WIDGETS;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 133 "gtkdialog_lexer.l"
{
	Token="<command>";    
	BEGIN(EMBEDDED);
	return COMM;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 139 "gtkdialog_lexer.l"
{
	Token="<if>";    
	BEGIN(EMBEDDED);
	return IF;           
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 145 "gtkdialog_lexer.l"
{
	Token="<while>";    
	BEGIN(EMBEDDED);
	return WHILE;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 151 "gtkdialog_lexer.l"
{
	Token = "operator";
	return gtkdialog_text[0];
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 156 "gtkdialog_lexer.l"
{
	Token = "variable";
	gtkdialog_lval.cval = g_strdup(gtkdialog_text);
	return EMB_VARIABLE;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 162 "gtkdialog_lexer.l"
{
	Token = "number";
	gtkdialog_lval.cval = g_strdup(gtkdialog_text);
	return EMB_NUMBER;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 168 "gtkdialog_lexer.l"
{ 
	BEGIN(0);
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 172 "gtkdialog_lexer.l"
{ 
	Token="</if>"; 
	return ENDCOMM;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 177 "gtkdialog_lexer.l"
{ 
	Token="</if>"; 
	return ENDIF;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 182 "gtkdialog_lexer.l"
{ 
	Token="</while>"; 
	return EWHILE;
}
	YY_BREAK
/*
	 * The widget tags.
	 */
case 21:
YY_RULE_SETUP
#line 191 "gtkdialog_lexer.l"
{ 
	Token="<window>"; 
	return(WINDOW);
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 196 "gtkdialog_lexer.l"
{ 
	Token="<window>"; 
	BEGIN(ST_TAG_ATTR);
	return(PART_WINDOW);  		
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 202 "gtkdialog_lexer.l"
{ 
	Token="</window>"; 
	return(EWINDOW);
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 208 "gtkdialog_lexer.l"
{ 
	Token="<notebook>"; 
	return(NOTEBOOK);
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 213 "gtkdialog_lexer.l"
{ 
	Token="<notebook>";
	BEGIN(ST_TAG_ATTR);
	return(PART_NOTEBOOK);
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 219 "gtkdialog_lexer.l"
{ 
	Token="</notebook>"; 
	return(ENOTEBOOK);
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 225 "gtkdialog_lexer.l"
{ 
	Token="<vbox>"; 
	return(VBOX);
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 230 "gtkdialog_lexer.l"
{ 
	Token="<vbox>"; 
	BEGIN(ST_TAG_ATTR);
	return(PART_VBOX);
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 236 "gtkdialog_lexer.l"
{ 
	Token="</vbox>"; 
	return(EVBOX);
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 242 "gtkdialog_lexer.l"
{ 
	Token="<hbox>"; 
	return(HBOX);
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 247 "gtkdialog_lexer.l"
{ 
	Token="<hbox>";
	BEGIN(ST_TAG_ATTR);
	return(PART_HBOX);
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 253 "gtkdialog_lexer.l"
{ 
	Token="</hbox>"; 
	return(EHBOX);
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 259 "gtkdialog_lexer.l"
{ 
	Token="<frame>"; 
	gtkdialog_lval.cval = "";  
	return(FRAME); 	
}
	YY_BREAK
case 34:
/* rule 34 can match eol */
YY_RULE_SETUP
#line 265 "gtkdialog_lexer.l"
{
	Token="<frame>";
	gtkdialog_lval.cval=strdup(&gtkdialog_text[7]);  
	gtkdialog_lval.cval[strlen(gtkdialog_lval.cval)-1] = 0;
	return FRAME; 
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 272 "gtkdialog_lexer.l"
{ 
	Token="</frame>"; 
	return(EFRAME);
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 278 "gtkdialog_lexer.l"
{ 
	Token="<text>"; 
	return(TEXT);
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 283 "gtkdialog_lexer.l"
{ 
	Token="<text>"; 
	BEGIN(ST_TAG_ATTR);
	return(PART_TEXT);
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 289 "gtkdialog_lexer.l"
{ 
	Token="</text>"; 
	return(ETEXT);
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 295 "gtkdialog_lexer.l"
{ 
	Token="<pixmap>"; 
	return(PIXMAP);
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 300 "gtkdialog_lexer.l"
{ 
	Token="</pixmap>"; 
	return(EPIXMAP); 
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 305 "gtkdialog_lexer.l"
{ 
	Token="<pixmap>"; 
	BEGIN(ST_TAG_ATTR);
	return(PART_PIXMAP);
}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 312 "gtkdialog_lexer.l"
{ 
	Token="<entry>"; 
	return(ENTRY);
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 317 "gtkdialog_lexer.l"
{ 
	Token="</entry>"; 
	return(EENTRY);
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 322 "gtkdialog_lexer.l"
{ 
	Token="<entry>"; 
	BEGIN(ST_TAG_ATTR);
	return(PART_ENTRY);
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 329 "gtkdialog_lexer.l"
{ 
	Token="<edit>"; 
	return(EDIT);
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 334 "gtkdialog_lexer.l"
{ 
	Token="<entry>"; 
	BEGIN(ST_TAG_ATTR);
	return(PART_EDIT);
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 340 "gtkdialog_lexer.l"
{ 
	Token="</edit>"; 
	return(EEDIT);
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 346 "gtkdialog_lexer.l"
{ 
	Token="<tree>";  
	return  TREE;
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 351 "gtkdialog_lexer.l"
{ 
	Token="<tree>";  
	BEGIN(ST_TAG_ATTR);
	return PART_TREE;
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 357 "gtkdialog_lexer.l"
{
	Token="</tree>"; 
	return ETREE;
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 363 "gtkdialog_lexer.l"
{ 
	Token="<chooser>"; 
	return(CHOOSER);
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 368 "gtkdialog_lexer.l"
{ 
	Token="</chooser>"; 
	return(ECHOOSER);
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 373 "gtkdialog_lexer.l"
{ 
	Token="<chooser>";  
	BEGIN(ST_TAG_ATTR);
	return PART_CHOOSER;
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 380 "gtkdialog_lexer.l"
{ 
	Token="<button>"; 
	return(BUTTON);
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 385 "gtkdialog_lexer.l"
{ 
	Token="</button>"; 
	return(EBUTTON);
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 390 "gtkdialog_lexer.l"
{ 
	//g_message("PART_BUTTON: '%s'", gtkdialog_text);
	Token="<button>";  
	BEGIN(ST_TAG_ATTR);
	return PART_BUTTON;
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 397 "gtkdialog_lexer.l"
{ Token="<button>"; return(BUTTONOK);  			}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 398 "gtkdialog_lexer.l"
{ Token="<button>"; return(BUTTONCANCEL);  		}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 399 "gtkdialog_lexer.l"
{ Token="<button>"; return(BUTTONHELP);  		}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 400 "gtkdialog_lexer.l"
{ Token="<button>"; return(BUTTONYES);  		}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 401 "gtkdialog_lexer.l"
{ Token="<button>"; return(BUTTONNO);  			}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 403 "gtkdialog_lexer.l"
{ Token="<checkbox>"; return(CHECKBOX);       		}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 404 "gtkdialog_lexer.l"
{ Token="</checkbox>"; return(ECHECKBOX);     		}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 405 "gtkdialog_lexer.l"
{ Token="<checkbox>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_CHECKBOX);  				}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 409 "gtkdialog_lexer.l"
{ Token="<radiobutton>"; return(RADIO);      		}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 410 "gtkdialog_lexer.l"
{ Token="</radiobutton>"; return(ERADIO);    		}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 411 "gtkdialog_lexer.l"
{ Token="<radiobutton>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_RADIO);  					}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 415 "gtkdialog_lexer.l"
{ Token="<progressbar>"; return(PROGRESSBAR);      	}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 416 "gtkdialog_lexer.l"
{ Token="</progressbar>"; return(EPROGRESSBAR);    	}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 417 "gtkdialog_lexer.l"
{ Token="<progressbar>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_PROGRESSBAR);  				}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 422 "gtkdialog_lexer.l"
{ Token="<radio>"; return(RADIO);  			}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 423 "gtkdialog_lexer.l"
{ Token="</radio>"; return(ERADIO);  			}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 425 "gtkdialog_lexer.l"
{ Token="<gvim>"; return(GVIM);  			}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 426 "gtkdialog_lexer.l"
{ Token="</gvim>"; return(EGVIM);  			}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 428 "gtkdialog_lexer.l"
{ Token="<combobox>"; return(COMBOBOX);		}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 429 "gtkdialog_lexer.l"
{ Token="<combobox>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_COMBOBOX); 					}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 432 "gtkdialog_lexer.l"
{ Token="</combobox>"; return(ECOMBOBOX);	}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 434 "gtkdialog_lexer.l"
{ Token="<list>";  return(LIST);  			}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 435 "gtkdialog_lexer.l"
{ Token="<list>";  
					  BEGIN(ST_TAG_ATTR);
					  return(PART_LIST); 					}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 438 "gtkdialog_lexer.l"
{ Token="</list>"; return(ELIST);  			}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 440 "gtkdialog_lexer.l"
{ Token="<table>"; return(TABLE); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 441 "gtkdialog_lexer.l"
{ Token="<table>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_TABLE); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 444 "gtkdialog_lexer.l"
{ Token="</table>"; return(ETABLE); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 446 "gtkdialog_lexer.l"
{ Token="<menubar>"; return(MENUBAR); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 447 "gtkdialog_lexer.l"
{ Token="<menubar>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_MENUBAR); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 450 "gtkdialog_lexer.l"
{ Token="</menubar>"; return(EMENUBAR); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 452 "gtkdialog_lexer.l"
{ Token="<menu>"; return(MENU); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 453 "gtkdialog_lexer.l"
{ Token="<menu>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_MENU); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 456 "gtkdialog_lexer.l"
{ Token="</menu>"; return(EMENU); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 458 "gtkdialog_lexer.l"
{ Token="<menuitem>"; return(MENUITEM); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 459 "gtkdialog_lexer.l"
{ Token="<menuitem>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_MENUITEM); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 462 "gtkdialog_lexer.l"
{ Token="</menuitem>"; return(EMENUITEM); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 464 "gtkdialog_lexer.l"
{ Token="<menuitemseparator>"; return(MENUITEMSEPARATOR); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 465 "gtkdialog_lexer.l"
{ Token="</menuitemseparator>"; return(EMENUITEMSEPARATOR); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 467 "gtkdialog_lexer.l"
{ Token="<menuitemseparator>"; return(MENUITEMSEPARATOR); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 468 "gtkdialog_lexer.l"
{ Token="</menuitemseparator>"; return(EMENUITEMSEPARATOR); }
	YY_BREAK
/**************************************************************
	 * Thunor: Newly supported widgets.
	 **************************************************************/
case 97:
YY_RULE_SETUP
#line 473 "gtkdialog_lexer.l"
{ Token="<hseparator>"; return(HSEPARATOR); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 474 "gtkdialog_lexer.l"
{ Token="<hseparator>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_HSEPARATOR); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 477 "gtkdialog_lexer.l"
{ Token="</hseparator>"; return(EHSEPARATOR); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 479 "gtkdialog_lexer.l"
{ Token="<vseparator>"; return(VSEPARATOR); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 480 "gtkdialog_lexer.l"
{ Token="<vseparator>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_VSEPARATOR); }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 483 "gtkdialog_lexer.l"
{ Token="</vseparator>"; return(EVSEPARATOR); }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 485 "gtkdialog_lexer.l"
{ Token="<comboboxtext>"; return(COMBOBOXTEXT); }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 486 "gtkdialog_lexer.l"
{ Token="<comboboxtext>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_COMBOBOXTEXT); }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 489 "gtkdialog_lexer.l"
{ Token="</comboboxtext>"; return(ECOMBOBOXTEXT); }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 491 "gtkdialog_lexer.l"
{ Token="<comboboxentry>"; return(COMBOBOXENTRY); }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 492 "gtkdialog_lexer.l"
{ Token="<comboboxentry>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_COMBOBOXENTRY); }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 495 "gtkdialog_lexer.l"
{ Token="</comboboxentry>"; return(ECOMBOBOXENTRY); }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 497 "gtkdialog_lexer.l"
{ Token="<hscale>"; return(HSCALE); }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 498 "gtkdialog_lexer.l"
{ Token="<hscale>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_HSCALE); }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 501 "gtkdialog_lexer.l"
{ Token="</hscale>"; return(EHSCALE); }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 503 "gtkdialog_lexer.l"
{ Token="<vscale>"; return(VSCALE); }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 504 "gtkdialog_lexer.l"
{ Token="<vscale>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_VSCALE); }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 507 "gtkdialog_lexer.l"
{ Token="</vscale>"; return(EVSCALE); }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 509 "gtkdialog_lexer.l"
{ Token="<spinbutton>"; return(SPINBUTTON); }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 510 "gtkdialog_lexer.l"
{ Token="<spinbutton>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_SPINBUTTON); }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 513 "gtkdialog_lexer.l"
{ Token="</spinbutton>"; return(ESPINBUTTON); }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 515 "gtkdialog_lexer.l"
{ Token="<timer>"; return(TIMER); }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 516 "gtkdialog_lexer.l"
{ Token="<timer>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_TIMER); }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 519 "gtkdialog_lexer.l"
{ Token="</timer>"; return(ETIMER); }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 521 "gtkdialog_lexer.l"
{ Token="<togglebutton>"; return(TOGGLEBUTTON); }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 522 "gtkdialog_lexer.l"
{ Token="<togglebutton>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_TOGGLEBUTTON); }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 525 "gtkdialog_lexer.l"
{ Token="</togglebutton>"; return(ETOGGLEBUTTON); }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 527 "gtkdialog_lexer.l"
{ Token="<statusbar>"; return(STATUSBAR); }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 528 "gtkdialog_lexer.l"
{ Token="<statusbar>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_STATUSBAR); }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 531 "gtkdialog_lexer.l"
{ Token="</statusbar>"; return(ESTATUSBAR); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 533 "gtkdialog_lexer.l"
{ Token="<colorbutton>"; return(COLORBUTTON); }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 534 "gtkdialog_lexer.l"
{ Token="<colorbutton>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_COLORBUTTON); }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 537 "gtkdialog_lexer.l"
{ Token="</colorbutton>"; return(ECOLORBUTTON); }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 539 "gtkdialog_lexer.l"
{ Token="<fontbutton>"; return(FONTBUTTON); }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 540 "gtkdialog_lexer.l"
{ Token="<fontbutton>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_FONTBUTTON); }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 543 "gtkdialog_lexer.l"
{ Token="</fontbutton>"; return(EFONTBUTTON); }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 545 "gtkdialog_lexer.l"
{ Token="<terminal>"; return(TERMINAL); }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 546 "gtkdialog_lexer.l"
{ Token="<terminal>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_TERMINAL); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 549 "gtkdialog_lexer.l"
{ Token="</terminal>"; return(ETERMINAL); }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 551 "gtkdialog_lexer.l"
{ Token="<eventbox>"; return(EVENTBOX); }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 552 "gtkdialog_lexer.l"
{ Token="<eventbox>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_EVENTBOX); }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 555 "gtkdialog_lexer.l"
{ Token="</eventbox>"; return(EEVENTBOX); }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 557 "gtkdialog_lexer.l"
{ Token="<expander>"; return(EXPANDER); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 558 "gtkdialog_lexer.l"
{ Token="<expander>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_EXPANDER); }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 561 "gtkdialog_lexer.l"
{ Token="</expander>"; return(EEXPANDER); }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 565 "gtkdialog_lexer.l"
{ Token="<label>"; return(LABEL);    			}
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 566 "gtkdialog_lexer.l"
{ Token="</label>"; return(ELABEL);  			}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 568 "gtkdialog_lexer.l"
{ Token="<item>"; return(ITEM);      			}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 569 "gtkdialog_lexer.l"
{ Token="</item>"; return(EITEM);    			}
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 570 "gtkdialog_lexer.l"
{ Token="<item>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_ITEM); 					}
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 574 "gtkdialog_lexer.l"
{ Token="<default>"; return(DEFAULT);  			}
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 575 "gtkdialog_lexer.l"
{ Token="</default>"; return(EDEFAULT);  		}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 577 "gtkdialog_lexer.l"
{ Token="<sensitive>"; return(SENSITIVE);  		}
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 578 "gtkdialog_lexer.l"
{ Token="</sensitive>"; return(ESENSITIVE);  	}
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 580 "gtkdialog_lexer.l"
{ Token="<sensitive>"; return(SENSITIVE);  		}
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 581 "gtkdialog_lexer.l"
{ Token="</sensitive>"; return(ESENSITIVE);  	}
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 583 "gtkdialog_lexer.l"
{ Token="<height>"; return(HEIGHT);  			}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 584 "gtkdialog_lexer.l"
{ Token="</height>"; return(EHEIGHT);  			}
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 586 "gtkdialog_lexer.l"
{ Token="<width>"; return(WIDTH);   			}
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 587 "gtkdialog_lexer.l"
{ Token="</width>"; return(EWIDTH);   			}
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 589 "gtkdialog_lexer.l"
{ Token="<input>"; return(INPUT);   			}
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 590 "gtkdialog_lexer.l"
{ Token="</input>"; return(EINPUT);   			}
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 591 "gtkdialog_lexer.l"
{ Token="<input file>"; return(INPUTFILE);   		}
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 592 "gtkdialog_lexer.l"
{ Token="<input file>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_INPUTFILE);   				}
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 595 "gtkdialog_lexer.l"
{ Token="<input>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_INPUT);   				}
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 599 "gtkdialog_lexer.l"
{ Token="<output>"; return(OUTPUT);   			}
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 600 "gtkdialog_lexer.l"
{ Token="</output>"; return(EOUTPUT);   		}
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 601 "gtkdialog_lexer.l"
{ Token="<output>"; return(OUTPUTFILE);   		}
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 603 "gtkdialog_lexer.l"
{ Token="<variable>"; return(VARIABLE);  		}
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 604 "gtkdialog_lexer.l"
{ Token="<variable>"; 
					  BEGIN(ST_TAG_ATTR);
					  return(PART_VARIABLE); 				}
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 607 "gtkdialog_lexer.l"
{ Token="</variable>"; return(EVARIABLE);  		}
	YY_BREAK
/*
	** The definition of action tags.
	*/
case 168:
YY_RULE_SETUP
#line 613 "gtkdialog_lexer.l"
{ Token="<action>"; return(ACTION);  			}
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 614 "gtkdialog_lexer.l"
{ Token="<action>";
					  BEGIN(ST_TAG_ATTR);
					  return(PART_ACTION); 					}
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 617 "gtkdialog_lexer.l"
{ Token="</action>"; return(EACTION);  			}
	YY_BREAK
case 171:
/* rule 171 can match eol */
YY_RULE_SETUP
#line 624 "gtkdialog_lexer.l"
{ 
	Token=g_strdup(gtkdialog_text); 
	gtkdialog_error("Unknown end tag.");  
}
	YY_BREAK
case 172:
/* rule 172 can match eol */
YY_RULE_SETUP
#line 629 "gtkdialog_lexer.l"
{ 
	Token=g_strdup(gtkdialog_text); 
	gtkdialog_error("Unknown tag.");      
}
	YY_BREAK
/*
					 * The quoted string. It can contain anything, except
					 * unescaped double quote.
					 */
case 173:
YY_RULE_SETUP
#line 638 "gtkdialog_lexer.l"
{
					  Token = "double quote";
					  BEGIN(ST_QUOTED_STRING);				}
	YY_BREAK
case 174:
/* rule 174 can match eol */
YY_RULE_SETUP
#line 642 "gtkdialog_lexer.l"
{
					  yymore();						}
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 645 "gtkdialog_lexer.l"
{
					  yymore();						}
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 648 "gtkdialog_lexer.l"
{
					  Token = gtkdialog_text;
					  gtkdialog_lval.cval = g_strdup(gtkdialog_text);
					  gtkdialog_lval.cval[strlen(gtkdialog_lval.cval) - 1] = '\0';
					  BEGIN(0);
					  return STRING;
					  							}
	YY_BREAK
/*
					 * An unquoted string can contain anything except 
					 * unescaped '<'.
					 */
case 177:
YY_RULE_SETUP
#line 660 "gtkdialog_lexer.l"
{
					  Token = "string";
					  BEGIN(ST_STRING);
					  yymore();
												}
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 665 "gtkdialog_lexer.l"
{
					  Token = "string";
					  yymore();
												}
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 671 "gtkdialog_lexer.l"
{
					  yymore();
												}
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 675 "gtkdialog_lexer.l"
{
					  yymore();
												}
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 679 "gtkdialog_lexer.l"
{
					  gtkdialog_lval.cval = g_strdup(gtkdialog_text);
					  gtkdialog_lval.cval[strlen(gtkdialog_lval.cval) - 1] = '\0';
					  unput('<');
					  BEGIN(0);
					  return STRING;
					  							}
	YY_BREAK
case 182:
/* rule 182 can match eol */
YY_RULE_SETUP
#line 689 "gtkdialog_lexer.l"
{
					  ++linenumber;
												}
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 692 "gtkdialog_lexer.l"
{
					  /* */
												}
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 696 "gtkdialog_lexer.l"
{
					  /* we do nothing, this is a dropped char. */
												}
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 699 "gtkdialog_lexer.l"
ECHO;
	YY_BREAK
#line 2805 "gtkdialog_lexer.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(EMBEDDED):
			case YY_STATE_EOF(ST_TAG_ATTR):
			case YY_STATE_EOF(ST_QUOTED_TAGATTR):
			case YY_STATE_EOF(ST_STRING):
			case YY_STATE_EOF(ST_QUOTED_STRING):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed gtkdialog_in at a new source and called
			 * gtkdialog_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = gtkdialog_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( gtkdialog_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * gtkdialog_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of gtkdialog_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			gtkdialog_restart(gtkdialog_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) gtkdialog_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 922 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 922 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 921);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up gtkdialog_text */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					gtkdialog_restart(gtkdialog_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( gtkdialog_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve gtkdialog_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void gtkdialog_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        gtkdialog_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            gtkdialog__create_buffer(gtkdialog_in,YY_BUF_SIZE );
	}

	gtkdialog__init_buffer(YY_CURRENT_BUFFER,input_file );
	gtkdialog__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void gtkdialog__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		gtkdialog_pop_buffer_state();
	 *		gtkdialog_push_buffer_state(new_buffer);
     */
	gtkdialog_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	gtkdialog__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (gtkdialog_wrap()) processing, but the only time this flag
	 * is looked at is after gtkdialog_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void gtkdialog__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	gtkdialog_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE gtkdialog__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) gtkdialog_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gtkdialog__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) gtkdialog_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in gtkdialog__create_buffer()" );

	b->yy_is_our_buffer = 1;

	gtkdialog__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with gtkdialog__create_buffer()
 * 
 */
    void gtkdialog__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		gtkdialog_free((void *) b->yy_ch_buf  );

	gtkdialog_free((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a gtkdialog_restart() or at EOF.
 */
    static void gtkdialog__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	gtkdialog__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then gtkdialog__init_buffer was _probably_
     * called from gtkdialog_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void gtkdialog__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		gtkdialog__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void gtkdialog_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	gtkdialog_ensure_buffer_stack();

	/* This block is copied from gtkdialog__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from gtkdialog__switch_to_buffer. */
	gtkdialog__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void gtkdialog_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	gtkdialog__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		gtkdialog__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void gtkdialog_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)gtkdialog_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gtkdialog_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)gtkdialog_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gtkdialog_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE gtkdialog__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) gtkdialog_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gtkdialog__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	gtkdialog__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to gtkdialog_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       gtkdialog__scan_bytes() instead.
 */
YY_BUFFER_STATE gtkdialog__scan_string (yyconst char * yystr )
{
    
	return gtkdialog__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to gtkdialog_lex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE gtkdialog__scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) gtkdialog_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in gtkdialog__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = gtkdialog__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in gtkdialog__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gtkdialog_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		gtkdialog_text[gtkdialog_leng] = (yy_hold_char); \
		(yy_c_buf_p) = gtkdialog_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		gtkdialog_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int gtkdialog_get_lineno  (void)
{
        
    return gtkdialog_lineno;
}

/** Get the input stream.
 * 
 */
FILE *gtkdialog_get_in  (void)
{
        return gtkdialog_in;
}

/** Get the output stream.
 * 
 */
FILE *gtkdialog_get_out  (void)
{
        return gtkdialog_out;
}

/** Get the length of the current token.
 * 
 */
int gtkdialog_get_leng  (void)
{
        return gtkdialog_leng;
}

/** Get the current token.
 * 
 */

char *gtkdialog_get_text  (void)
{
        return gtkdialog_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void gtkdialog_set_lineno (int  line_number )
{
    
    gtkdialog_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see gtkdialog__switch_to_buffer
 */
void gtkdialog_set_in (FILE *  in_str )
{
        gtkdialog_in = in_str ;
}

void gtkdialog_set_out (FILE *  out_str )
{
        gtkdialog_out = out_str ;
}

int gtkdialog_get_debug  (void)
{
        return gtkdialog__flex_debug;
}

void gtkdialog_set_debug (int  bdebug )
{
        gtkdialog__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from gtkdialog_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    gtkdialog_in = stdin;
    gtkdialog_out = stdout;
#else
    gtkdialog_in = (FILE *) 0;
    gtkdialog_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * gtkdialog_lex_init()
     */
    return 0;
}

/* gtkdialog_lex_destroy is for both reentrant and non-reentrant scanners. */
int gtkdialog_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		gtkdialog__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		gtkdialog_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	gtkdialog_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    gtkdialog_free ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * gtkdialog_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *gtkdialog_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *gtkdialog_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void gtkdialog_free (void * ptr )
{
	free( (char *) ptr );	/* see gtkdialog_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 699 "gtkdialog_lexer.l"



static gchar *
process_string(gchar *str)
{
	//fprintf(stderr, "%s(): Input = '%s'\n", __func__, str);
	// FIXME: Well, this will come tomorrow...
	return g_strdup(str);
}


